# Authors credits

## ANTIPASTI

Core developer:

- Kevin Michalewicz [[Website](https://kevinmichalewicz.com/)|[Github](https://github.com/kevinmicha)|[Email](mailto:k.michalewicz22@imperial.ac.uk?subject=[GitHub]%20ANTIPASTI)]

Supervisors:

- Mauricio Barahona [[Website](https://www.imperial.ac.uk/people/m.barahona/)|[Github](https://github.com/mauriciobarahona)|[Email](mailto:m.barahona@imperial.ac.uk?subject=[GitHub]%20ANTIPASTI)]
- Barbara Bravi [[Website](https://www.imperial.ac.uk/people/b.bravi21)|[Github](https://github.com/bravib)|[Email](mailto:b.bravi21@imperial.ac.uk?subject=[GitHub]%20ANTIPASTI)]